Merge 10952656

Merged-In: I99ad17cdfa0324e623b4674332922c8bf2db263e
Change-Id: Ib9e965e47015ff54230ee7863bc4ec4bac510133
diff --git a/res/values-zh-rHK/strings.xml b/res/values-zh-rHK/strings.xml
index f4685ec..890ff10 100644
--- a/res/values-zh-rHK/strings.xml
+++ b/res/values-zh-rHK/strings.xml
@@ -19,8 +19,8 @@
     <string name="app_name" msgid="170210454004696382">"金鑰鏈"</string>
     <string name="title_select_cert" msgid="3588447616418041699">"選擇憑證"</string>
     <string name="requesting_application" msgid="1589142627467598421">"應用程式「%s」已提出憑證要求。選擇憑證即可讓應用程式今後在伺服器上使用這個身分。"</string>
-    <string name="requesting_server" msgid="5832565605998634370">"應用程式已識別提出要求的伺服器為「%s」。除非你信任應用程式,否則請勿允許應用程式存取憑證。"</string>
-    <string name="install_new_cert_message" msgid="4451971501142085495">"你可以從外部儲存裝置中副檔名為 %1$s 或 %2$s 的 PKCS#12 檔案安裝憑證。"</string>
+    <string name="requesting_server" msgid="5832565605998634370">"應用程式已識別提出要求的伺服器為「%s」。除非您信任應用程式,否則請勿允許應用程式存取憑證。"</string>
+    <string name="install_new_cert_message" msgid="4451971501142085495">"您可以從外部儲存裝置中副檔名為 %1$s 或 %2$s 的 PKCS#12 檔案安裝憑證。"</string>
     <string name="allow_button" msgid="3030990695030371561">"選取"</string>
     <string name="deny_button" msgid="3766539809121892584">"拒絕"</string>
     <string name="loading_certs_message" msgid="2152223341043639547">"%s 正在檢查憑證…"</string>
diff --git a/src/com/android/keychain/KeyChainActivity.java b/src/com/android/keychain/KeyChainActivity.java
index d735044..6b09d78 100644
--- a/src/com/android/keychain/KeyChainActivity.java
+++ b/src/com/android/keychain/KeyChainActivity.java
@@ -738,8 +738,9 @@
             } catch (IllegalArgumentException ignored) {
                 Log.d(TAG, "attempt to set grant on a non-existent alias", ignored);
                 respondWithAlias(null);
-            } catch (Exception ignored) {
-                // Catchall so we always call mKeyChainAliasResponse
+            } catch (Exception | AssertionError ignored) {
+                // Catchall so we always call mKeyChainAliasResponse.
+                // AssertionError is thrown in case of failure to connect to the service.
                 Log.e(TAG, "error while granting access", ignored);
                 respondWithAlias(null);
             }